@@ -1,5 +1,5 @@
 package HTML::Latemp::NavLinks::GenHtml;
-$HTML::Latemp::NavLinks::GenHtml::VERSION = '0.2.8';
+$HTML::Latemp::NavLinks::GenHtml::VERSION = '0.2.9';
 use warnings;
 use strict;
 
@@ -71,7 +71,6 @@ sub _get_buttons
     return \@buttons;
 }
 
-
 1;
 
 __END__
@@ -87,7 +86,7 @@ navigation links.
 
 =head1 VERSION
 
-version 0.2.8
+version 0.2.9
 
 =head1 SYNOPSIS
 
@@ -105,27 +104,6 @@ Initialises the object.
 
 Calculates the HTML and returns it.
 
-=head1 AUTHOR
-
-Shlomi Fish, L<http://www.shlomifish.org/> .
-
-=head1 BUGS
-
-Please report any bugs or feature requests to
-C<bug-html-latemp-navlinks-genhtml@rt.cpan.org>, or through the web interface at
-L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=HTML-Latemp-NavLinks-GenHtml>.
-I will be notified, and then you'll automatically be notified of progress on
-your bug as I make changes.
-
-=head1 ACKNOWLEDGEMENTS
-
-=head1 COPYRIGHT & LICENSE
-
-Copyright 2005 Shlomi Fish, All Rights Reserved.
-
-This program is free software; you can redistribute it and/or modify it
-under the terms of the MIT X11 license.
-
 =for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
 =head1 SUPPORT
