@@ -1,5 +1,5 @@
 package HTML::Latemp::NavLinks::GenHtml::ArrowImages;
-$HTML::Latemp::NavLinks::GenHtml::ArrowImages::VERSION = '0.2.8';
+$HTML::Latemp::NavLinks::GenHtml::ArrowImages::VERSION = '0.2.9';
 use strict;
 use warnings;
 
@@ -102,7 +102,6 @@ sub get_total_html
         . "\n</ul>";
 }
 
-
 1;
 
 __END__
@@ -117,7 +116,7 @@ HTML::Latemp::NavLinks::GenHtml::ArrowImages - A class to generate the image-bas
 
 =head1 VERSION
 
-version 0.2.8
+version 0.2.9
 
 =head1 SYNOPSIS
 
@@ -143,25 +142,6 @@ Can be overrided. Should return the base of the image filename of the module.
 
 Calculates and returns the final HTML.
 
-=head1 AUTHOR
-
-Shlomi Fish, L<http://www.shlomifish.org/> .
-
-=head1 BUGS
-
-Please report any bugs or feature requests to
-C<bug-html-latemp-navlinks-genhtml@rt.cpan.org>, or through the web interface at
-L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=HTML-Latemp-NavLinks-GenHtml>.
-I will be notified, and then you'll automatically be notified of progress on
-your bug as I make changes.
-
-=head1 COPYRIGHT & LICENSE
-
-Copyright 2005 Shlomi Fish, All Rights Reserved.
-
-This program is free software; you can redistribute it and/or modify it
-under the terms of the MIT X11 license.
-
 =for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
 =head1 SUPPORT
